from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x08\x00\x55\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x9b\x08\x00\x00\x00\x00\x00\x18\x05\x1d\xad\xca\x2d\x41\xd2\x27\xe5\xf4\xd5\xf2\xba\xbb\x66\xa0\x00\x00\x00\x00\x00\x00\x00\x00\x8f\xc5\xd5\xce\x5c\xdb\x3b\xce\x6c\x71\x80\x33\xa7\xf8\x2f\xa2\xdc\x34\x45\xba\xe0\x7d\xc4\x50\x0e\x0f\x89\xea\xd2\x82\x74\x13\xf6\xbb\xe0\x78\x53\xf4\xb0\x82\x60\x1c\x77\xc5\x24\x47\x48\x47\x00\x5b\x26\xbc\x11\x61\x1b\x18\xb9\x26\x5f\xf5\xe1\x28\x0b\x1e\xb0\x61\x31\x5d\x4e\xbe\xd8\xe5\x6e\xe5\x63\x55\xe0\x08\xdb\x92\x02\xac\x5d\xef\x1f\xbd\x47\x59\xbb\xa4\xf0\xa0\x79\x8b\x80\x50\xdd\x0c\x04\x37\x1b\xa5\xac\x5c\x1d\xf7\x98\x6c\xe6\xa5\xc7\x33\x5b\x93\xec\x50\x85\x5c\x75\x4d\x80\x97\xc3\x4d\xa0\x1c\x4c\x46\xd4\xdb\x28\xdf\x52\xa5\x09\x28\x3f\xe8\x0f\x13\x23\xdd\x82\xab\x85\x6e\x4f\xd5\x13\x79\xed\x37\x1a\xd5\xd7\x6f\x6f\xf9\xd6\x3b\x3e\x37\x04\xe5\xf2\x5c\x37\xcb\xf4\xb5\x0c\xdc\x08\x05\x6a\xbd\x19\xd0\x40\x07\x86\x05\x42\xe5\xac\x40\x17\x81\xd0\xc6\xd1\x7e\x5c\x33\x13\xe2\x91\x93\x68\x40\x48\x7a\x84\x15\xea\x16\x77\x21\x81\x64\x04\xd4\xe5\xa6\x15\x56\xae\x8e\x70\xa8\x18\xb8\x06\x99\xc9\x73\x1a\x0c\x98\xa6\x9c\xc5\x67\x6a\xa1\xc1\xf4\x43\x25\x22\x05\x7e\xae\xe7\x95\xe3\x6c\x04\x57\x72\x9d\x5c\x74\x84\x7b\x70\x36\xac\xb0\x28\xd4\x92\x0f\x89\xa2\xb8\x36\x4d\x04\x8a\x92\x3c\x5e\x95\x96\x28\x5c\xdf\xcc\x07\xe3\x95\xbf\x38\xaf\x01\x5c\xd0\xd2\xfe\x69\xac\x60\x07\x65\x95\xaa\x82\x48\x0d\xff\x62\x7b\xad\x30\xb8\xfe\x1d\x2d\x21\x71\x8d\xe1\x24\x13\x44\x7d\x16\x73\x43\xf0\xd8\x53\x50\xc5\x9e\x83\x3a\x68\x0b\xff\xd1\x46\x08\xa4\x77\x13\xee\xc4\x57\x39\x3d\xbe\x39\x80\x15\x84\x39\xa5\x78\x3f\x50\xd8\xc8\x17\xc3\x0f\xcc\xdc\x27\x23\x94\x0c\x09\xa9\xb6\xf8\x0a\x9a\x65\xa4\x54\x6e\xf8\x00\x73\x33\x07\xca\xee\x8b\x4d\x77\xf7\x7e\xdc\x8a\xf6\xae\x3d\x8d\x3a\xa5\x2f\xd3\xe6\x8a\x91\xee\x93\xdb\xcb\xca\x12\xd1\xef\x61\xf8\xa0\xf2\xf5\x06\x22\xd2\x9f\x9b\x25\x1d\x04\x34\x7d\x1e\x80\xc4\xe8\xd3\x03\x9e\x19\x1b\x1f\xbc\xa8\x78\x3e\xd8\x15\xdd\xf2\x5a\x7c\xb5\xd3\xc0\xd0\x8e\x04\x4d\x14\x1a\x21\xf6\x14\x2e\x18\x3d\x52\x44\x59\xa7\x31\x77\x37\xc2\x54\x08\xa9\x17\x5c\xe5\xde\x90\x3b\x58\x6f\x33\x73\x72\x58\x54\xd8\xc8\xb4\x95\x61\xd3\xad\xfa\xd7\xe3\xf7\xd6\xc5\xc2\xd8\x27\x27\x58\xf2\x93\x70\x41\x76\x00\x9d\x04\xdc\xa2\xfa\x95\xb9\x79\xfc\xe4\xdf\x49\x87\x7b\x94\xec\xdd\xbf\x9c\x72\xa6\xe8\x92\xe1\xcd\x96\x48\xee\x47\xeb\xc0\x19\x14\x90\x08\xa7\xc0\x93\xee\x4a\x80\x36\xc4\x81\x12\xf2\x86\xa2\xc2\x91\x9c\xbf\x2b\x18\xf2\xf7\x13\xb3\x01\x19\xdc\x87\x59\x09\x73\xb6\x8a\x9b\x64\xf8\x78\xae\x30\xd8\xdd\x0f\x58\x71\xa6\xec\x41\xa9\x0b\x3d\x87\x35\x06\x68\x20\x16\x11\x18\x53\xf5\x14\x6e\xf6\xa8\xe3\xd5\xe7\xfe\xd9\x67\xee\xe2\x38\xa9\x94\x19\x97\x04\x5e\x76\xac\xcd\xe1\x5d\xf5\x0a\x49\x6a\x63\x9d\xc8\xa5\x3e\x65\x00\xc5\x28\x91\x47\x16\x5b\xf5\xd7\xba\x26\x10\x04\x6e\x67\x6b\x94\x5f\x7c\x75\x11\x0d\x04\xd3\xa4\x2f\xeb\xa8\x7b\x89\xa8\xdd\xb1\x4c\xef\x23\x3c\xf0\xe5\xa1\x5d\x68\x5f\x68\x8f\x4a\x4a\xda\xdf\x6b\x64\x40\x9e\xde\x06\xec\xfc\xe0\x72\x42\x0c\xe4\xbd\xe6\x25\x66\xf3\x86\x9d\x08\x57\x28\x95\xee\x53\x10\x16\xd6\x89\x43\xa7\xda\xb7\x02\x9a\x19\x04\x81\xaf\xfe\x00\xbc\xa8\xb8\xd5\x3c\x45\x9f\x19\x9a\x2a\xb0\xb6\x82\xbd\x5d\x22\x38\x80\x81\xb2\x94\x89\x3b\xac\xcb\x1a\xa7\xc8\x85\x5a\x45\x16\xd2\x4d\x40\x86\xa7\x2c\xaa\xbc\x94\x0c\x84\x58\x83\x3a\xe1\x3b\x08\x61\x5d\x6a\xbb\x1d\x69\xc7\x9b\x5b\x01\x38\x91\x98\xa3\x49\x65\x85\x46\x9a\x8f\x3e\x41\xa1\x11\x24\xc4\x2e\xac\xd5\xe1\x00\x01\xd9\x9b\x5c\xe8\x99\x3a\x93\xb9\x38\xfc\x9d\xce\x82\x5b\xe6\xe7\xe7\xe3\xb6\xb6\x15\x6c\x57\x1b\x5c\x84\x72\x68\x76\xcf\xba\xba\x4d\x75\x23\x4d\x7a\xe5\x14\x6a\x10\xae\x19\x87\xe3\xf7\x79\x89\xd3\x22\x80\xd1\xef\x6b\x54\xc3\x94\x9a\x93\x80\x7e\x6e\xfe\xd8\xbf\x54\x7f\x4a\xd3\x71\x53\x15\x13\xf7\xe1\xf5\x3f\x52\x69\xf7\x6b\xea\x20\x94\x1f\x75\x1d\xb4\xc5\x68\xa6\x13\xb4\x33\x99\x95\x57\x3c\x55\xb5\xf3\xef\x1c\x76\xf9\xc0\xe3\x64\xd6\xda\xae\xca\xf0\xb4\x94\x57\xd0\xbb\xd0\x82\xa8\xae\xcc\xcf\xc9\xf4\x21\x62\xd5\xb6\x89\x84\x22\x34\x57\xf6\x14\xc6\x26\x9c\xb4\x9f\x01\xb2\x60\xaf\x67\x96\xdb\x44\xf0\xed\x36\x9f\xeb\xf7\xb8\xda\xd3\xe7\xf8\x35\xa0\x5a\x83\x36\x83\x2e\x6a\x13\x46\xc7\x6c\xc7\x2c\x86\x13\xc4\x4b\x44\xf6\x07\x4b\x8a\x5a\x87\x91\x0a\x57\x31\x89\x4e\x8c\xc4\x5b\xf6\x30\x71\xba\x16\x85\xa4\xa4\xab\x99\xca\x73\x41\x2e\xf0\xf7\x5e\xa9\x9f\xed\xa8\x4f\xf8\x34\x7c\x5c\x2a\x11\x9e\x99\x4c\xb8\x2e\x7d\xd4\x04\xca\x85\xc8\x9a\x54\x58\x91\x17\xa5\xbe\x55\x7e\x6d\xc0\xc5\x03\xfb\xdd\x77\x2f\x8d\x99\x52\x73\x32\xaf\xa0\x36\xd6\x5b\x36\x63\x25\x9e\xbb\x00\xb9\x27\x0e\xed\xa4\xef\xc2\x38\x58\xa5\xd8\xb8\x19\x94\x2c\x5f\x7b\xeb\xfc\x71\x52\x2f\x6a\xcc\xae\xd0\x08\x14\x17\x43\x92\x2f\x74\xcd\x28\x0d\xa1\xca\x20\x54\x9c\xe3\xd8\x9c\x99\x21\xfc\xb9\xe3\x85\xb8\x53\xc4\x70\x78\x9f\xbe\x52\xdb\x66\x52\xf2\x9f\x38\x31\x25\xd2\x5b\x8d\x66\xdd\xc2\x52\x84\xf0\x7a\x7d\x35\x78\x7e\xab\x3f\xd0\xeb\x7e\x79\x7e\x6c\xdc\x1c\x3e\xf2\x96\xd8\xc2\xa9\x69\x30\x4a\x08\xa9\x08\x53\x78\x99\xe0\xb7\x55\xea\x6e\x04\x97\xf3\x9f\xfd\xff\x02\xa6\xac\x88\xea\x96\x95\x37\x78\x5e\x72\x01\x6a\x52\xca\xff\xb2\xe7\x5d\x62\x91\x51\x03\xc5\x6f\x0e\x31\x73\x28\x50\x55\x7f\xc7\x2e\x77\x42\xa8\x7b\xec\xed\xb0\x65\xf8\x33\xc6\xba\x85\x39\x56\x77\x3c\x62\x2e\xad\xa4\xb6\xb8\x5b\xed\xd7\x59\x87\x9d\xd9\x70\xb7\xa2\x56\x78\x4c\x13\x66\x66\x34\x21\x7a\xf7\xc0\xee\x8f\x95\xc8\xef\x18\x85\x64\x47\x4d\x98\xfc\x1a\x2a\x14\xc5\x5c\xe5\x85\x11\x0b\x80\x9d\x3c\xdf\xd1\x60\xdc\x4d\xd3\xf3\x80\xf3\xad\x75\x59\xca\x34\x17\xdb\x7d\x33\xea\xdc\xf1\xf6\x21\xb2\xc3\xac\x23\x7d\x3e\x53\xb7\xdd\x8b\xee\x5d\x46\xe6\xfe\xe0\xf5\x4a\xb2\xae\xa2\x3d\x32\x41\x02\x69\x25\xca\x0e\x7b\x86\x36\x62\xd5\x91\x18\xa7\xe1\x8d\xb8\xc8\xe4\xd7\x61\x10\x01\x61\xb8\x7a\x31\x06\x8c\xcc\x11\x91\x1b\xef\xf1\x7c\x87\x54\xcd\xfc\x29\x8d\x1c\x3e\xc3\xb8\x72\x3f\x72\xce\x48\x21\x43\x88\x0b\x31\xbd\xfa\x9f\x25\x93\x22\x78\x59\xab\x3c\xb2\xe1\x00\x44\x7b\xcf\xd5\xf8\xbb\xab\x75\xe0\x0e\xce\x87\x9f\x3f\x65\x18\x73\xa1\xe0\x08\xf8\xfb\x6b\xfc\xfc\x23\x10\x2b\x70\x19\x47\xdd\x1c\x80\x7b\x7e\xf1\xcc\xcd\xd3\x6b\xba\x50\x34\x40\x95\x4f\xa5\xbf\x97\x81\xec\xb6\x25\x29\x05\x23\x86\xbd\xac\xa7\x83\xed\xef\x1b\xea\xdf\xfb\x97\x94\x7c\x2c\x07\x0a\x76\xb3\x01\xcc\x61\x3e\x5a\x48\xf2\x85\x9e\xd9\x12\xc4\x1e\xb0\x57\x3c\x6c\x26\x58\x3c\x55\x65\x4c\x27\x52\x10\xdc\x10\xb7\xdc\x7a\x30\x82\xae\x89\x4e\x13\xb2\x4e\xd1\xd0\x6e\xfa\x7c\x74\xd9\x9b\x79\x35\x50\xd3\x58\x3e\xc3\x3f\x9f\x98\xf2\x1f\xf7\x2d\x3f\x77\xec\x06\xf6\x97\x26\x6f\x81\x81\xb4\xf4\xe0\x7d\x52\xd0\x2c\x1c\xa2\xa5\xa9\x08\xa6\x97\x01\xbb\xb4\x17\xf4\x1a\x01\xc2\x94\x8a\xd5\xae\x8a\xeb\xf3\x00\x37\x41\x78\xad\x4f\x66\x2f\x92\xa2\xda\xf9\x16\x4c\xcc\x41\x9f\xf6\xb9\xde\x6e\x72\x07\x57\x7d\xa9\x77\xc5\x15\x39\x7d\x5e\xc9\xa3\x9f\x77\x03\x49\x13\xcf\x39\xbd\xca\x9f\xb4\xc4\x96\x61\x26\x28\xe8\xb4\x4f\x99\xe5\x79\xeb\xa8\xc2\xbc\xec\x42\x69\xc5\x32\xad\x56\x17\x0d\x53\x91\x44\x36\xd6\xa6\x0f\x2d\xf8\xfe\x0e\x38\xca\x2b\xc8\x84\x9c\x4d\xd7\x15\xba\x31\xdb\x45\x08\xe8\x1d\xb9\x15\x05\xcc\xad\x9c\x6c\x08\x63\x53\x96\x10\xc2\x60\xdf\x45\xc7\xb2\xa8\xb1\x07\x10\x1a\xfa\x08\x05\x9f\xd9\xee\xb4\x30\x4f\xe9\xda\xe9\xb4\x59\x7f\x93\xf6\x21\x86\x03\x8d\x64\xad\xc8\x4b\x4f\xe7\x2b\x72\xfe\xc8\x31\x22\x19\x49\x87\xd7\x93\xd5\x6e\xe6\x25\xfa\xaa\xe1\x92\x36\xd5\xa3\x41\x5b\x27\xfd\x9d\xfb\x4d\x70\xd8\x75\x98\xb8\x78\xc5\x88\xc3\x94\xcf\x8c\x71\x90\x38\x53\x3c\xfc\x86\x47\xbd\x1f\x97\xa2\xef\x8b\x70\xf7\xd1\xdd\xf6\xb2\x0c\x0c\xa7\x4f\x8a\xab\x0d\x92\x50\xc3\x8d\x2b\x0f\x45\x8f\x05\x8f\x3c\x05\x2c\x53\xdc\xf8\xef\xf5\x14\x0f\xe8\x65\x2c\x71\x82\x90\x69\xfa\xa7\xce\xdd\xd1\xaf\x02\x1a\x85\xd9\x26\x2d\xd8\xe9\x9d\xb9\x8b\xc5\x1b\x1a\x29\x21\xe2\x7b\x2b\x2a\xa8\x92\x7c\x85\x26\x57\xff\x6f\xa8\x9b\x2f\x9f\xc3\xf2\xa5\x0e\x46\x18\x25\x1b\xe7\xfb\x79\xee\x6c\xba\x2d\x1b\xab\xa0\x86\xf4\x7c\x41\xb4\x61\x95\xb8\xf9\xe7\x1a\xc9\xfa\xeb\x3f\xea\x55\x58\x0c\x5e\x33\xba\xc9\xe2\x17\xbf\xa9\x22\x55\xd6\xa8\xbd\xfc\x5c\x31\xe2\x1c\xdd\xf3\xb3\xf2\xd8\x01\xb9\xb2\x2f\x22\xee\x25\x8d\x51\xf0\xa4\x5b\x05\x64\x1e\xa7\x2a\xe7\xe6\xbe\xb9\xf8\x7c\x30\x12\xf1\x37\x81\x50\x79\x75\x2a\x10\xcb\x9f\x9f\xe6\x3a\xa9\x26\x7c\x13\xaa\x13\x09\xee\x61\x3f\x2b\xd2\x2b\x2d\x69\x5b\x10\xce\x46\xab\xca\xb8\xce\xa6\x92\x6d\x48\xeb\x93\x9c\x89\x9e\x3a\x13\xea\xce\x65\xef\x18\x86\x6a\x78\x1e\x2a\xc3\x7b\xeb\x8c\x85\x4c\x2c\xfa\x6e\x19\xfc\x6f\xaf\xc5\xac\x1f\x60\x2b\x88\x92\xe5\x90\x8c\x5c\xa8\x9b\x83\x1f\xcd\xc1\x4b\xd1\x76\x04\xc5\x5a\x9c\x3a\xfe\x2c\x6e\xfd\x49\x49\x95\x00\xfa\xc2\x15\x12\x5d\xb9\x28\x3a\xce\xa1\x18\x74\x11\x91\xdb\x04\x97\x56\xd9\x53\xdc\xd8\xd5\x5e\x06\x90\xa3\x5c\x9d\x6a\x16\x9f\x94\xc9\x42\x1b\x97\x51\x63\x2b\xc8\xaa\xaa\x1e\xfb\x4b\x90\xc1\x5c\x48\xda\xb5\xbe\x49\xe1\x52\xc3\x89\x3c\x44\xc9\xfa\x25\x89\xd5\xab\x67\xbf\x0f\x2b\x4f\x9c\x81\xdc\x17\xe5\x6d\xe6\xac\xcc\xa2\x24\x5b\x21\x32\x98\xa8\x13\x0e\xbc\x72\x45\xcc\x7a\xe1\x5a\x35\x2e\xd9\x9d\x25\xa7\x60\x6f\xf9\xcd\x5e\x21\xff\xbd\xdf\x0f\x16\x26\x2e\x22\x9e\xf5\x02\xcd\x87\x43\x93\x06\x79\x81\x42\x8a\x04\x89\xf5\xf9\xee\x1d\x34\x02\x5f\xf5\x24\x97\x10\x9c\xf7\x0f\xf6\x01\x80\x3d\xc0\xf9\xf4\xe5\xb3\xd9\x1e\x13', 2)

# cleanup
del pyarmor_runtime

